package Win32::HtmlHelp;

use 5.006000;
use strict;
use warnings;

require Exporter;

our @ISA = qw(Exporter);

# Items to export into callers namespace by default. Note: do not export
# names by default without a very good reason. Use EXPORT_OK instead.
# Do not simply export all your public functions/methods/constants.

# This allows declaration	use Win32::HtmlHelp ':all';
# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
# will save memory.
our %EXPORT_TAGS = ( 'all' => [ qw( 
  DisplayTopic DisplayToc DisplayIndex CloseAll
	
) ] );

our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );

our @EXPORT = qw(
	
);

our $VERSION = '0.01';

require XSLoader;
XSLoader::load('Win32::HtmlHelp', $VERSION);

# Preloaded methods go here.

1;
__END__
# Below is stub documentation for your module. You'd better edit it!

=head1 NAME

Win32::HtmlHelp - Perl extension for the HTML Help API

=head1 SYNOPSIS

  use Win32::HtmlHelp 'DisplayTopic';
  DisplayTopic( "MyHelp.chm", "html/intro.html" );

=head1 DESCRIPTION

The HTML Help application programming interface (API) enables a Windows 
program to create a help window that displays a help topic.

This Perl module provides access to a few HTML Help API calls.

=head2 Functions

=over

=item * DisplayTopic( chmfilename [, topic] )

Opens a help topic in a specified help window. 

C<chmfilename> specifies a compiled help (.chm) file, or a specific topic 
within a compiled help file.

The optional parameter C<topic> is a topic within a compiled help file.

A compiled help file retains the folder structure in which it was organized 
before compilation, unless the option to compile flat has been selected.

For example, if a project is organized in three folders (one for HTML 
files, one for images, and one for style sheets), the help file will 
contain those same folders internally. The folder in which the project file 
resides is considered the root. 

To correctly link to a topic file, you must specify the full path. The 
following example specifies an overview topic:

  DisplayTopic( "HelpFile.chm", "Html/Overview/Topic.htm" );

where Overview is a folder within the Html folder.

To specify a topic within a compiled help file, use the following syntax:

  DisplayTopic( "HelpFile.chm::/Html/Overview/Topic.htm" );

=item * DisplayToc( chmfilename [, topic] )

Same as above. (!?)

=item * DisplayIndex( chmfilename [, keyword] )

C<chmfilename> specifies a compiled help (.chm) file, or a specific topic 
within a compiled help file.

The optional parameter C<keyword> specifies the keyword to select in the 
index (.hhk) file. 

  DisplayIndex( "HelpFile.chm", "foo" );

=item * CloseAll()

This command closes any compiled help (.chm) files that are open by the 
calling program.

=back

=head2 EXPORT

None by default.

The function names must be explicitly exported.

=head1 SEE ALSO

The Microsoft HTML Help SDK:
  
  http://msdn2.microsoft.com/en-us/library/ms670169.aspx

=head1 AUTHOR

J-L Morel E<lt>jl_morel@bribes.orgE<gt>

Home page: http://www.bribes.org/perl

=head1 COPYRIGHT AND LICENSE

Copyright (c) 2008 J-L Morel. All rights reserved.

This program is free software; you can redistribute it and/or modify it under
the same terms as Perl itself.

=cut
